@@ -1,14 +1,21 @@
-/* Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2009, 2023, Oracle and/or its affiliates.
  
  This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; version 2 of the License.
- 
+ it under the terms of the GNU General Public License, version 2.0,
+ as published by the Free Software Foundation.
+
+ This program is also distributed with certain software (including
+ but not limited to OpenSSL) that is licensed under separate terms,
+ as designated in a particular file or component or in included license
+ documentation.  The authors of MySQL hereby grant you an additional
+ permission to link the program and your derivative works with the
+ separately licensed software that they have included with MySQL.
+
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
- 
+ GNU General Public License, version 2.0, for more details.
+
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
@@ -47,7 +54,7 @@
 #define HAVE_POLL_H 1
 #define HAVE_PWD_H 1
 #define HAVE_STRINGS_H 1
-#define HAVE_SYS_CDEFS_H 1
+/* #undef HAVE_SYS_CDEFS_H */
 #define HAVE_SYS_IOCTL_H 1
 #define HAVE_SYS_MMAN_H 1
 #define HAVE_SYS_RESOURCE_H 1
@@ -61,7 +68,6 @@
 #define HAVE_SYS_PARAM_H 1
 #define HAVE_FNMATCH_H 1
 #define HAVE_SYS_UN_H 1
-#define HAVE_VIS_H 1
 /* #undef HAVE_SASL_SASL_H */
 
 /* Libevent */
@@ -169,9 +175,9 @@
 /* #undef WORDS_BIGENDIAN */
 
 /* Type sizes */
-#define SIZEOF_VOIDP     4
-#define SIZEOF_CHARP     4
-#define SIZEOF_LONG      4
+#define SIZEOF_VOIDP     8
+#define SIZEOF_CHARP     8
+#define SIZEOF_LONG      8
 #define SIZEOF_SHORT     2
 #define SIZEOF_INT       4
 #define SIZEOF_LONG_LONG 8
@@ -181,6 +187,7 @@
 #define HAVE_ULONG 1
 #define HAVE_U_INT32_T 1
 #define HAVE_STRUCT_TIMESPEC
+#define HAVE_TM_GMTOFF 1
 
 /* Support for tagging symbols with __attribute__((visibility("hidden"))) */
 #define HAVE_VISIBILITY_HIDDEN 1
@@ -214,7 +221,7 @@
 /*
  * Platform specific CMake files
  */
-#define MACHINE_TYPE "earmv6hf"
+#define MACHINE_TYPE "alpha"
 /* #undef HAVE_LINUX_LARGE_PAGES */
 /* #undef HAVE_SOLARIS_LARGE_PAGES */
 /* #undef HAVE_SOLARIS_ATOMIC */
@@ -225,6 +232,7 @@
 /* #undef IPV6_V6ONLY */
 /* This should mean case insensitive file system */
 /* #undef FN_NO_CASE_SENSE */
+/* #undef APPLE_ARM */
 
 /*
  * From main CMakeLists.txt
@@ -276,12 +284,20 @@
 /* #undef HAVE_NCURSES_H */
 #define USE_LIBEDIT_INTERFACE 1
 #define HAVE_HIST_ENTRY 1
-/* #undef USE_NEW_EDITLINE_INTERFACE */
+#define USE_NEW_EDITLINE_INTERFACE 1
+#define EDITLINE_HAVE_COMPLETION_CHAR 1
+/* #undef EDITLINE_HAVE_COMPLETION_INT */
 
 /*
  * Libedit
  */
-/* #undef HAVE_DECL_TGOTO */
+/* #undef HAVE_GETLINE */
+/* #undef HAVE___SECURE_GETENV */
+/* #undef HAVE_SECURE_GETENV */
+/* #undef HAVE_VIS */
+/* #undef HAVE_UNVIS */
+/* #undef HAVE_GETPW_R_DRAFT */
+/* #undef HAVE_GETPW_R_POSIX */
 
 /*
  * DTrace
@@ -389,15 +405,15 @@
 #define DOT_FRM_VERSION 6
 #define MYSQL_VERSION_MAJOR 5
 #define MYSQL_VERSION_MINOR 7
-#define MYSQL_VERSION_PATCH 26
+#define MYSQL_VERSION_PATCH 44
 #define MYSQL_VERSION_EXTRA ""
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.7.26"
+#define PACKAGE_STRING "MySQL Server 5.7.44"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.7.26"
-#define VERSION "5.7.26"
+#define PACKAGE_VERSION "5.7.44"
+#define VERSION "5.7.44"
 #define PROTOCOL_VERSION 10
 
 /*
